@@ -185,7 +185,7 @@ typedef struct {
   // - creation timestamp for the record
   uInt32 modcount_created;
 
-	// Version 5 fields start here
+  // Version 5 fields start here
   // ===========================
   // CRC of the record's data after the last modification
   uInt16 dataCRC;
@@ -525,7 +525,7 @@ typedef struct {
   // - transport related profile flags
   uInt32 transpFlags;
   // - general profile flags
-	uInt32 profileFlags;
+  uInt32 profileFlags;
   // - general profile ints
   uInt32 profileExtra1;
   uInt32 profileExtra2;
@@ -658,7 +658,7 @@ public:
   // properties
   // - activtion switch (for making it inactive e.g. in server case)
   bool fBinfileDSActive;
-	#ifdef CHANGEDETECTION_AVAILABLE
+  #ifdef CHANGEDETECTION_AVAILABLE
   // - we have change detection, but we can be set to enable change detection by CRC,
   //   or verifying DB reported changes by CRC to avoid pseudo-changes (only touched, but not modified records).
   bool fCRCChangeDetection;
@@ -671,7 +671,7 @@ public:
   // - if set, the compare reference time for changelog updates is set to end-of-session time
   //   Note: before 3.2.0.32, this was hardcoded via SYNCTIME_IS_ENDOFSESSION. Now SYNCTIME_IS_ENDOFSESSION
   //         only defines the default value for this setting
-  bool fCmpRefTimeStampAtEnd;  
+  bool fCmpRefTimeStampAtEnd;
   // public methods
   // - init a default target for this datastore
   virtual void initTarget(
@@ -779,6 +779,9 @@ protected:
   /// called for SyncML 1.1 if remote wants number of changes.
   /// Must return -1 no NOC value can be returned
   virtual sInt32 getNumberOfChanges(void);
+  /// checks change log for already known changes
+  virtual bool hasPendingChangesForNextSync();
+
   // Simple custom DB access interface methods
   /// sync login (into this database)
   /// @note might be called several times (auth retries at beginning of session)
@@ -941,7 +944,7 @@ private:
   /// private helper to prepare for apiSaveAdminData()
   localstatus SaveAdminData(bool aSessionFinished, bool aSuccessful);
   /// load target record for this datastore
-	localstatus loadTarget(bool aCreateIfMissing, cAppCharP aRemoteDBID=NULL);
+  localstatus loadTarget(bool aCreateIfMissing, cAppCharP aRemoteDBID=NULL);
   /* %%% seems obsolete - never called from anywhere
   // private utils
   #ifdef OBJECT_FILTERING
@@ -967,6 +970,10 @@ private:
   // - entire change log, loaded into memory for quick reference during write phase
   TChangeLogEntry *fLoadedChangeLog;
   uInt32 fLoadedChangeLogEntries;
+  // - true if there are known pending changes for the next sync
+  //   (necessary for hasPendingChangesForNextSync()
+  //   because not all of the change log is always in memory)
+  bool fHasPendingChanges;
   #endif // CHECKSUM_CHANGELOG
   /// pending maps for Resume
   TBinFile fPendingMaps; ///< pending map binfile
