@@ -1,7 +1,7 @@
 /*
  *  File:         MultiFieldItemType.cpp
  *
- *  Author:			  Lukas Zeller (luz@plan44.ch)
+ *  Author:       Lukas Zeller (luz@plan44.ch)
  *
  *  TMultiFieldItemType
  *    Type consisting of multiple data fields (TItemField objects)
@@ -69,6 +69,29 @@ void TMultiFieldTypeConfig::clear(void)
 class TMFTypeFuncs {
 public:
 
+  // integer SYNCMODESUPPORTED(string mode)
+  //
+  // True if the remote datastore is known to support the specific mode
+  // (usually because it sent SyncCap including the mode), false if unknown
+  // or not supported.
+  //
+  // Only works inside scripts which work on remote items.
+  static void func_SyncModeSupported(TItemField *&aTermP, TScriptContext *aFuncContextP)
+  {
+    bool supported = false;
+    TMultiFieldItemType *mfitP = static_cast<TMultiFieldItemType *>(aFuncContextP->getCallerContext());
+    if (mfitP->fFirstItemP &&
+        mfitP->fFirstItemP->getRemoteItemType()) {
+      TSyncDataStore *related = mfitP->fFirstItemP->getRemoteItemType()->getRelatedDatastore();
+      if (related) {
+        std::string mode;
+        aFuncContextP->getLocalVar(0)->getAsString(mode);
+        supported = related->syncModeSupported(mode);
+      }
+    }
+    aTermP->setAsInteger(supported);
+  }; // func_SyncModeSupported
+
   // void SETFILTERALL(integer all)
   // sets if all records in the syncset need to checked against filter or only those that are new or changed
   static void func_SetFilterAll(TItemField *&aTermP, TScriptContext *aFuncContextP)
@@ -166,12 +189,17 @@ public:
   }; // func_IgnoreUpdate
 
 
-  // void MERGEFIELDS()
+  // void MERGEFIELDS(mode = 0)
+  // Optional mode parameter determines the result of the merge.
+  // 0 = according to config, 1 = loosing item is overwritten, 2 = winning item is overwritten
   static void func_MergeFields(TItemField *&aTermP, TScriptContext *aFuncContextP)
   {
     TMultiFieldItemType *mfitP = static_cast<TMultiFieldItemType *>(aFuncContextP->getCallerContext());
-    if (mfitP->fFirstItemP)
-      mfitP->fFirstItemP->standardMergeWith(*(mfitP->fSecondItemP),mfitP->fChangedFirst,mfitP->fChangedSecond);
+    if (mfitP->fFirstItemP) {
+      TItemField *argP = aFuncContextP->getLocalVar(0);
+      mfitP->fFirstItemP->standardMergeWith(*(mfitP->fSecondItemP),mfitP->fChangedFirst,mfitP->fChangedSecond,
+                                            (argP && argP->isAssigned()) ? argP->getAsInteger() : 0);
+    }
   }; // func_MergeFields
 
 
@@ -215,7 +243,7 @@ public:
     if (!mfitP->fFirstItemP) aTermP->setAsInteger(SYSYNC_NOT_COMPARABLE);
     else {
       aTermP->setAsInteger(
-        mfitP->fFirstItemP->standardCompareWith(*(mfitP->fSecondItemP),mfitP->fEqMode,OBJDEBUGTEST(mfitP,DBG_SCRIPTS+DBG_DATA+DBG_MATCH)) ? 1 : 0
+        mfitP->fFirstItemP->standardCompareWith(*(mfitP->fSecondItemP),mfitP->fEqMode,OBJDEBUGTEST(mfitP,DBG_SCRIPTS+DBG_DATA+DBG_MATCH))
       );
     }
   }; // func_CompareFields
@@ -232,7 +260,16 @@ public:
     }
   }; // func_CompareFields
 
-
+  // int MERGEMODE()
+  // returns mode of merging, see MERGEFIELDS()
+  static void func_MergeMode(TItemField *&aTermP, TScriptContext *aFuncContextP)
+  {
+    TMultiFieldItemType *mfitP = static_cast<TMultiFieldItemType *>(aFuncContextP->getCallerContext());
+    if (!mfitP->fFirstItemP) aTermP->unAssign(); // no merging
+    else {
+      aTermP->setAsInteger(mfitP->fMergeMode);
+    }
+  }; // func_MergeMode
 
   #endif
 
@@ -321,6 +358,7 @@ const uInt8 param_IntArg[] = { VAL(fty_integer) };
 
 // builtin functions for datastore-context table
 const TBuiltInFuncDef DataTypeFuncDefs[] = {
+  { "SYNCMODESUPPORTED", TMFTypeFuncs::func_SyncModeSupported, fty_integer, 1, param_StrArg },
   { "SETFILTERALL", TMFTypeFuncs::func_SetFilterAll, fty_none, 1, param_IntArg },
   #ifdef SYSYNC_TARGET_OPTIONS
   { "SIZELIMIT", TMFTypeFuncs::func_Limit, fty_integer, 0, NULL },
@@ -333,13 +371,14 @@ const TBuiltInFuncDef DataTypeFuncDefs[] = {
   { "DELETEWINS", TMFTypeFuncs::func_DeleteWins, fty_none, 0, NULL },
   { "PREVENTADD", TMFTypeFuncs::func_PreventAdd, fty_none, 0, NULL },
   { "IGNOREUPDATE", TMFTypeFuncs::func_IgnoreUpdate, fty_none, 0, NULL },
-  { "MERGEFIELDS", TMFTypeFuncs::func_MergeFields, fty_none, 0, NULL },
+  { "MERGEFIELDS", TMFTypeFuncs::func_MergeFields, fty_none, 1, param_oneOptInteger },
   { "WINNINGCHANGED", TMFTypeFuncs::func_WinningChanged, fty_integer, 0, NULL },
   { "LOOSINGCHANGED", TMFTypeFuncs::func_LoosingChanged, fty_integer, 0, NULL },
   { "SETWINNINGCHANGED", TMFTypeFuncs::func_SetWinningChanged, fty_none, 1, param_IntArg },
   { "SETLOOSINGCHANGED", TMFTypeFuncs::func_SetLoosingChanged, fty_none, 1, param_IntArg },
   { "COMPAREFIELDS", TMFTypeFuncs::func_CompareFields, fty_integer, 0, NULL },
   { "COMPARISONMODE", TMFTypeFuncs::func_ComparisonMode, fty_string, 0, NULL },
+  { "MERGEMODE", TMFTypeFuncs::func_MergeMode, fty_integer, 0, NULL },
   #endif
   { "SYNCOP", TMFTypeFuncs::func_SyncOp, fty_string, 0, NULL },
   { "REJECTITEM", TMFTypeFuncs::func_RejectItem, fty_none, 1, param_IntArg },
@@ -767,18 +806,19 @@ void TMultiFieldItemType::mergeItems(
   TMultiFieldItem &aLoosingItem,
   bool &aChangedWinning,
   bool &aChangedLoosing,
-  TLocalEngineDS *aDatastoreP
+  TLocalEngineDS *aDatastoreP,
+  int mode
 )
 {
   #ifndef SCRIPT_SUPPORT
   // just do standard merge
-  aWinningItem.standardMergeWith(aLoosingItem,aChangedWinning,aChangedLoosing);
+  aWinningItem.standardMergeWith(aLoosingItem,aChangedWinning,aChangedLoosing,mode);
   return;
   #else
   // if no script use standard merging
   string &script = static_cast<TMultiFieldTypeConfig *>(fTypeConfigP)->fMergeScript;
   if (script.empty()) {
-    aWinningItem.standardMergeWith(aLoosingItem,aChangedWinning,aChangedLoosing);
+    aWinningItem.standardMergeWith(aLoosingItem,aChangedWinning,aChangedLoosing,mode);
     return;
   }
   // execute script to perform merge
@@ -789,6 +829,7 @@ void TMultiFieldItemType::mergeItems(
   fChangedFirst = aChangedWinning;
   fChangedSecond = aChangedLoosing;
   fCurrentSyncOp = fDsP->fCurrentSyncOp;
+  fMergeMode = mode;
   TScriptContext::execute(
     aDatastoreP->fReceivingTypeScriptContextP ?
       aDatastoreP->fReceivingTypeScriptContextP :
