@@ -42,6 +42,7 @@ TStdLogicDS::TStdLogicDS(
 ) :
   TLocalEngineDS(aDSConfigP, aSessionP, aName, aCommonSyncCapMask)
   #ifdef MULTI_THREAD_DATASTORE
+  ,fMultiThread(NULL)
   ,fStartSyncStatus(aSessionP) // a thread-private status command to store status ocurring during threaded startDataAccessForServer()
   #endif
 {
@@ -133,6 +134,17 @@ localstatus TStdLogicDS::logicMakeAdminReady(cAppCharP aDataStoreURI, cAppCharP
       // remote should see our (probably changed) devInf
       PDEBUGPRINTFX(DBG_PROTO,("First time sync or config changed since last sync -> remote should see our devinf"));
       fSessionP->remoteMustSeeDevinf();
+    } else if (IS_CLIENT && canRestart()) {
+      // When a client can restart, it must tell the server before
+      // asking for the server's DevInf, because restart capability is
+      // negotiated with a SyncMode extension which is only sent by
+      // the server if it has seen the client indicate that it
+      // supports these extensions by sending its own. If the server
+      // somehow didn't store our DevInf, it'll ask for it, but then
+      // it may be too late, so we pro-actively always send it when
+      // restarting is possible.
+      PDEBUGPRINTFX(DBG_PROTO,("Client needs to negotiate restart capability -> remote should see our devinf"));
+      fSessionP->remoteMustSeeDevinf();
     }
     // empty saved anchors if first time sync (should be empty anyway, but...)
     if (fFirstTimeSync) {
@@ -302,7 +314,7 @@ localstatus TStdLogicDS::performStartSync(void)
   fNumRefOnlyItems=0;
   if (sta==LOCERR_OK) {
     // now get data from DB
-    if (!isRefreshOnly() || (isSlowSync() && isResuming())) {
+    if (!isRefreshOnly() || (isRefreshOnly() && isCacheData()) || (isSlowSync() && isResuming())) {
       // not only updating from client, so read all items now
       // Note: for a resumed slow updating from client only, we need the
       //   currently present syncset as well as we need it to detect
@@ -474,9 +486,9 @@ bool TStdLogicDS::threadedStartSync(void)
   PDEBUGPRINTFX(DBG_HOT,(
     "******* started &html;<a href=\"%s_%lu%s\" target=\"_blank\">&html;background thread id=%lu&html;</a>&html; for reading sync set",
     getDbgLogger()->getDebugFilename(), // href base
-    fStartSyncThread.getid(), // plus thread
+    (long unsigned)fStartSyncThread.getid(), // plus thread
     getDbgLogger()->getDebugExt(), // plus extension
-    fStartSyncThread.getid()
+    (long unsigned)fStartSyncThread.getid()
   ));
   #endif
   return true; // started ok
@@ -569,7 +581,7 @@ localstatus TStdLogicDS::startDataAccessForServer(void)
       if (fStartSyncThread.waitfor(t<0 ? 0 : t * 1000)) {
         // background thread has terminated
         sta = fStartSyncThread.exitcode();
-        PDEBUGPRINTFX(DBG_HOT,("******* background thread for startSync() terminated with exit code=%ld, status sta=%hd", fStartSyncThread.exitcode(),sta));
+        PDEBUGPRINTFX(DBG_HOT,("******* background thread for startSync() terminated with exit code=%ld, status sta=%hd", (long)fStartSyncThread.exitcode(),sta));
         // initialisation is now complete
         fInitializing=false;
       } // if
@@ -880,15 +892,16 @@ bool TStdLogicDS::logicGenerateSyncCommandsAsServer(
     syncopcmdP=NULL;
     // possibly, we have a NULL command here (e.g. in case it could not be generated due to MaxObjSize restrictions)
     if (cmdP) {
-      if (!fSessionP->issuePtr(cmdP,aNextMessageCommands,aInterruptedCommandP)) {
-        alldone=false; // issue failed (no room in message), not finished so far
-        break;
-      }
-      // count item sent
+      // We pass the command to the issue mechanism - last chance to count is here.
+      // Note: the command might be queued and actually sent in a subsequent message.
       fItemsSent++; // overall counter for statistics
       itemcount++; // per message counter
-      // send event (but no check for abort)
-      DB_PROGRESS_EVENT(this,pev_itemsent,fItemsSent,getNumberOfChanges(),0);
+      DB_PROGRESS_EVENT(this,pev_itemsent,fItemsSent,getNumberOfChanges(),0); // send event (but no check for abort)
+      // now issue
+      if (!fSessionP->issuePtr(cmdP,aNextMessageCommands,aInterruptedCommandP)) {
+        alldone=false; // issue failed (no room in message), not finished so far
+        break; // stop trying to issue more commands
+      }
     }
   }; // while not aborted and not message full
   // we are not done until all aNextMessageCommands are also out
@@ -1039,19 +1052,23 @@ bool TStdLogicDS::logicGenerateSyncCommandsAsClient(
     syncopcmdP=NULL;
     // possibly, we have a NULL command here (e.g. in case it could not be generated due to MaxObjSize restrictions)
     if (cmdP) {
-      if (!fSessionP->issuePtr(cmdP,aNextMessageCommands,aInterruptedCommandP)) {
-        alldone=false; // issue failed (no room in message), not finished so far
-        break;
-      }
-      // count item sent
+      // We pass the command to the issue mechanism - last chance to count is here.
+      // Note: the command might be queued and actually sent in a subsequent message.
       fItemsSent++;
-      // send event and check for abort
       #ifdef PROGRESS_EVENTS
+      // send progress event and check for abort
       if (!DB_PROGRESS_EVENT(this,pev_itemsent,fItemsSent,getNumberOfChanges(),0)) {
         implEndDataRead(); // terminate reading
         fSessionP->AbortSession(500,true,LOCERR_USERABORT);
         return false; // error
       }
+      #endif
+      // issue now
+      if (!fSessionP->issuePtr(cmdP,aNextMessageCommands,aInterruptedCommandP)) {
+        alldone=false; // issue failed (no room in message), not finished so far
+        break;
+      }
+      #ifdef PROGRESS_EVENTS
       // check for "soft" suspension
       if (!SESSION_PROGRESS_EVENT(fSessionP,pev_suspendcheck,NULL,0,0,0)) {
         fSessionP->SuspendSession(LOCERR_USERSUSPEND);
@@ -1169,9 +1186,21 @@ TMultiFieldItem *TStdLogicDS::mergeWithDatabaseVersion(TSyncItem *aSyncItemP, bo
   return dbVersionItemP;
 } // TStdLogicDS::mergeWithDatabaseVersion
 
+enum LogicItemOp
+{
+  LOGIC_ITEM_WRITE,
+  LOGIC_ITEM_REPLACE_FALLBACK,
+  LOGIC_ITEM_ADD_FALLBACK
+};
 
-
-
+struct TLogicSyncItemAux : public TSyncItemAux
+{
+  bool fIrregular;
+  bool fShouldBeVisible;
+  bool fVisibleInSyncset;
+  TSyncItem *fSyncItemP;
+  LogicItemOp fOp;
+};
 
 // called to process incoming item operation
 // Method takes ownership of syncitemP in all cases
@@ -1185,6 +1214,10 @@ bool TStdLogicDS::logicProcessRemoteItem(
   bool irregular=false;
   bool shouldbevisible=aVisibleInSyncset;
   string datatext;
+  LogicItemOp op;
+  // Must be kept alive for the duration of the entire call,
+  // in case that we need to resume.
+  TSyncItem *origSyncItemP=syncitemP;
 
   TP_DEFIDX(li);
   TP_SWITCH(li,fSessionP->fTPInfo,TP_database);
@@ -1197,13 +1230,56 @@ bool TStdLogicDS::logicProcessRemoteItem(
       aStatusCommand.setStatusCode(sta);
     }
     else {
+      TLogicSyncItemAux *aux = static_cast<TLogicSyncItemAux *>(origSyncItemP->getAux(TSyncItem::STD_LOGIC_DS));
+
       // show
       DEBUGPRINTFX(DBG_DATA,(
-        "TStdLogicDS::logicProcessRemoteItem starting, SyncOp=%s, RemoteID='%s', LocalID='%s'",
-        SyncOpNames[syncitemP->getSyncOp()],
-        syncitemP->getRemoteID(),
-        syncitemP->getLocalID()
+        "TStdLogicDS::logicProcessRemoteItem %p %s, SyncOp=%s, RemoteID='%s', LocalID='%s'",
+        origSyncItemP,
+        aux ? "resuming" : "starting",
+        SyncOpNames[origSyncItemP->getSyncOp()],
+        origSyncItemP->getRemoteID(),
+        origSyncItemP->getLocalID()
       ));
+
+      // Same approach as in TLocalEngineDS::engProcessRemoteItemAsServer():
+      // jump directly to the point where we left the last time we where
+      // called for this item.
+      if (aux) {
+        irregular = aux->fIrregular;
+        shouldbevisible = aux->fShouldBeVisible;
+        aVisibleInSyncset = aux->fVisibleInSyncset;
+        syncitemP = aux->fSyncItemP;
+        op = aux->fOp;
+
+        switch (op) {
+        case LOGIC_ITEM_WRITE: goto do_write;
+        case LOGIC_ITEM_REPLACE_FALLBACK: goto do_replace_fallback;
+        case LOGIC_ITEM_ADD_FALLBACK: goto do_add_fallback;
+        }
+      }
+
+      if (false) {
+      again:
+#define CHECK_FOR_AGAIN(_op) \
+      if (aStatusCommand.getStatusCode() == LOCERR_AGAIN) { \
+        op = _op; \
+        goto again; \
+      }
+
+        if (!aux) {
+          aux = new TLogicSyncItemAux;
+          origSyncItemP->setAux(TSyncItem::STD_LOGIC_DS, aux);
+        }
+        aux->fIrregular = irregular;
+        aux->fShouldBeVisible = shouldbevisible;
+        aux->fVisibleInSyncset = aVisibleInSyncset;
+        aux->fSyncItemP = syncitemP;
+        aux->fOp = op;
+        aStatusCommand.setStatusCode(LOCERR_AGAIN);
+        return false;
+      }
+
       // now perform action
       if (syncitemP->getSyncOp()==sop_replace || syncitemP->getSyncOp()==sop_wants_replace) {
         // check if we should read before writing
@@ -1306,8 +1382,6 @@ bool TStdLogicDS::logicProcessRemoteItem(
             }
             #endif
             #endif
-            // - get rid of original
-            delete syncitemP;
             // - use new item for further processing
             syncitemP=refitemP;
           }
@@ -1367,8 +1441,10 @@ bool TStdLogicDS::logicProcessRemoteItem(
         }
         #endif
         // Now let derived class process the item
+      do_write:
         if (!implProcessItem(syncitemP,aStatusCommand))
           sta = aStatusCommand.getStatusCode(); // not successful, get error status code
+        CHECK_FOR_AGAIN(LOGIC_ITEM_WRITE);
       }
       // perform special case handling
       if (sta!=LOCERR_OK) {
@@ -1394,10 +1470,12 @@ bool TStdLogicDS::logicProcessRemoteItem(
                 syncitemP->setSyncOp(sop_replace);
                 irregular=true;
                 // - process again
+              do_replace_fallback:
                 if (implProcessItem(syncitemP,aStatusCommand)) {
                   aStatusCommand.setStatusCode(208); // client has won
                 }
                 else {
+                  CHECK_FOR_AGAIN(LOGIC_ITEM_REPLACE_FALLBACK);
                   // failed, return status
                   sta = aStatusCommand.getStatusCode();
                 }
@@ -1433,8 +1511,10 @@ bool TStdLogicDS::logicProcessRemoteItem(
                   // - process again (note that we are re-using the status command that might
                   //   already have a text item with an OS errir if something failed before)
                   sta=LOCERR_OK; // forget previous status
+                do_add_fallback:
                   if (!implProcessItem(syncitemP,aStatusCommand))
                     sta=aStatusCommand.getStatusCode(); // not successful, get error status code
+                  CHECK_FOR_AGAIN(LOGIC_ITEM_ADD_FALLBACK);
                 }
               }
             }
@@ -1472,6 +1552,7 @@ bool TStdLogicDS::logicProcessRemoteItem(
           (*aGUID)=syncitemP->getLocalID();
         }
       }
+      /* LOCERR_AGAIN */
       else {
         PDEBUGPRINTFX(DBG_ERROR,(
           "- Operation %s failed with SyncML status=%hd",
@@ -1482,6 +1563,8 @@ bool TStdLogicDS::logicProcessRemoteItem(
     } // if startDataWrite ok
     // anyway, we are done with this item, delete it now
     delete syncitemP;
+    if (syncitemP != origSyncItemP)
+      delete origSyncItemP;
     TP_START(fSessionP->fTPInfo,li);
     // done, return regular/irregular status
     return (sta==LOCERR_OK) && !irregular;
@@ -1489,6 +1572,8 @@ bool TStdLogicDS::logicProcessRemoteItem(
   SYSYNC_CATCH (...)
     // delete the item
     if (syncitemP) delete syncitemP;
+    if (syncitemP != origSyncItemP)
+      delete origSyncItemP;
     TP_START(fSessionP->fTPInfo,li);
     // re-throw
     SYSYNC_RETHROW;
@@ -1532,6 +1617,36 @@ localstatus TStdLogicDS::dsBeforeStateChange(TLocalEngineDSState aOldState,TLoca
       sta = startDataWrite();
     }
   } // client
+  #ifdef SYSYNC_SERVER
+  if (aNewState==dssta_serverseenclientmods) {
+    // Can only happen in server. Implement removal of unmatched items
+    // when in caching mode.
+    if (fCacheData && fSlowSync) {
+      TSyncItemPContainer::iterator pos=fItems.begin();
+      while (pos!=fItems.end()) {
+        TSyncItem *syncitemP = (*pos);
+        if (syncitemP->getSyncOp() == sop_wants_add) {
+          PDEBUGPRINTFX(DBG_DATA,("caching mode: remove unmatched item %s",
+                                  syncitemP->getLocalID()));
+          syncitemP->setSyncOp(sop_delete);
+          localstatus status = logicDeleteItemByID(*syncitemP);
+          if (status != LOCERR_OK) {
+            return status;
+          } else {
+            TSyncItemPContainer::iterator next = pos;
+            ++next;
+            delete syncitemP;
+            fItems.erase(pos);
+            pos = next;
+            fLocalItemsDeleted++;
+          }
+        } else {
+          ++pos;
+        }
+      }
+    }
+  }
+  #endif // SYSYNC_SERVER
   if (aNewState==dssta_completed && !isAborted()) {
     // finish writing data now anyway
     endDataWrite();
