@@ -310,8 +310,8 @@ static bool Get_Bias( string of, string ot, short &bias )
  *         or found and extracted
  */
 static bool GetTZInfo( cAppCharP     aText,
-                       cAppCharP     aIdent, 
-                       tChange      &c, 
+                       cAppCharP     aIdent,
+                       tChange      &c,
                        short        &cBias,
                        string       &cName,
                        sInt32        aNth, // take nth occurance, -1: take last
@@ -355,7 +355,7 @@ static bool GetTZInfo( cAppCharP     aText,
   if (!Get_Bias( of,ot, cBias ))                              return false;
 
   if ( rr.empty() ) {
-    // Happens when parsing STANDARD part of VTIMEZONE 
+    // Happens when parsing STANDARD part of VTIMEZONE
     // without DAYLIGHT saving.
   } else if (RRULE2toInternalR    ( rr.c_str(), &dtstart, r, aLogP )) {
     // Note: dtstart might have been adjusted by this call in case of DTSTART not meeting a occurrence for given RRULE
@@ -533,7 +533,7 @@ bool VTIMEZONEtoInternal( const char*    aText, // VTIMEZONE string to be parsed
 
   if  (s==0 && d==0) return false;
   okM= s<=1 && d<=1; // test if more than one section
- 
+
   // find best match for VTIMEZONE: checks name and rules
   // allows multiple timezone, if last is ok !
   if (!g) return false; // avoid crashes with g==NULL
@@ -675,7 +675,7 @@ bool internalToVTIMEZONE( timecontext_t  aContext,
                           sInt32         untilYear,
                           cAppCharP      aPrefIdent )
 {
-	// %%% note: untilYear needs to be implemented, is without functionality so far
+  // %%% note: untilYear needs to be implemented, is without functionality so far
 
   sInt16              yy= testYear;
   if (testYear==0)    yy= MyYear( g );
@@ -685,7 +685,7 @@ bool internalToVTIMEZONE( timecontext_t  aContext,
   tz_entry  t, tp;
   cAppCharP id;
   bool      withDST= false;
-  
+
   bool tzEnum= TCTX_IS_TZ( aContext );
   if  (tzEnum) {
     GetTZ( aContext, t, g, yy );
@@ -717,12 +717,12 @@ bool internalToVTIMEZONE( timecontext_t  aContext,
     } // if
   } // if
 
-	// make sure we get the right TZID string according to aPrefIdent
+  // make sure we get the right TZID string according to aPrefIdent
   string tzn = t.name;
   if (aPrefIdent || !tzEnum) {
-	  TimeZoneContextToName( aContext, tzn, g, aPrefIdent );
+    TimeZoneContextToName( aContext, tzn, g, aPrefIdent );
   }
-  
+
   // at least one STANDARD or DAYLIGHT info is mandatory
   aText=    Property      (    VTZ_ID,      escapeText( tzn ) ) +
             GenerateTZInfo( t, VTZ_STD, id, t.std, y_std, t_plus,t.bias, g, aLogP );
@@ -761,6 +761,8 @@ bool TzDaylightToContext( const char*    aText,     ///< DAYLIGHT property value
   timecontext_t cc, ccFirst, ccSlash;
 
   aContext= aStdOffs; // as default, convert it into a enum TZ
+  string    sSv;
+  bool      dbg= false; // currently no debugging
 
   do {
     if (s=="FALSE"      ) { s= ""; break; } // no DST
@@ -801,12 +803,15 @@ bool TzDaylightToContext( const char*    aText,     ///< DAYLIGHT property value
     StringSubst( s, ";", "/" );
 
     TimeZoneNameToContext( s.c_str(), aContext, g );
+    sSv= s; // make a copy for Olson name test later
 
     // if it perfectly fits to a named zone, take it
     if (GetTZ( std,dst, mins,minsDST, t, g )) { ccFirst= TCTX_UNKNOWN; // start with these defaults
                                                 ccSlash= TCTX_UNKNOWN;
                                                 cc     = TCTX_SYSTEM;
+      if   (dbg) printf( "lv1 s='%s' %d pref=%d\n", s.c_str(), aContext, aPreferredCtx );
       while   (FoundTZ( t, rslt, cc, g, false,  cc )) {
+        if (dbg) printf( "lv1 rslt='%s'\n", rslt.c_str() );
         if (s==rslt) { aContext= cc; break; }
         if (s.empty()) {
           if (ccFirst==TCTX_UNKNOWN) ccFirst= cc;
@@ -828,9 +833,12 @@ bool TzDaylightToContext( const char*    aText,     ///< DAYLIGHT property value
 
   ccFirst= TCTX_UNKNOWN; // start with these defaults
   cc     = TCTX_SYSTEM;
+  tCopy= t; // make the copy before
 
   if (GetTZ( aContext, t,        g )) {
+    if   (dbg) printf( "lv2 s='%s' %d\n", s.c_str(), aContext );
     if       (FoundTZ( t, s, cc, g, false, cc )) { // search by correct name first
+      if (dbg) printf( "lv2 s='%s' / loc='%s'\n", s.c_str(), t.location.c_str() );
       if (!(cc!=aPreferredCtx && cc==t_Greenwich)) { // take UTC for this case
         if (pUnk || cc==aPreferredCtx) { aContext= cc; return true; }
         if (ccFirst==TCTX_UNKNOWN)        ccFirst= cc; // keep it, just in case
@@ -842,20 +850,33 @@ bool TzDaylightToContext( const char*    aText,     ///< DAYLIGHT property value
     t.biasDST= 0; // no DST offset
     t.dynYear= "";
     ClrDST( t );
+    tCopy=  t;
   } // if
 
-                   tCopy= t;
+                 //tCopy= t;
                    tCopy.name = ""; // make more generic comparison
                    tCopy.ident= "";        cc= TCTX_SYSTEM;
   while  (FoundTZ( tCopy, s, cc, g, false, cc )) {
+    if (dbg) printf( "lv3 s='%s' loc='%s' cc=%d\n", s.c_str(), tCopy.location.c_str(), cc );
     if (!(cc!=aPreferredCtx && cc==t_Greenwich)) { // take UTC for this case
-      if (pUnk || cc==aPreferredCtx) { aContext= cc; return true; }
+      if (pUnk || cc==aPreferredCtx) {  ccFirst= cc; break; }
       if (ccFirst==TCTX_UNKNOWN)        ccFirst= cc; // keep it, just in case
     } // if
   } // while
 
   aContext= ccFirst;
-  return true;
+  bool ok= !TCTX_IS_UNKNOWN( aContext );
+  if (dbg) printf( "aContext=%d ok=%d\n", aContext, ok );
+
+  // if not ok, try to use Olson names
+  if (!ok) {               s= sSv;
+    TimeZoneNameToContext( s.c_str(), aContext, g, true );
+    if (dbg) printf( "lv4 s='%s' aContext=%d\n", s.c_str(), aContext );
+    ok= !TCTX_IS_UNKNOWN( aContext );
+  }
+
+  if (dbg) printf( "aContext=%d ok=%d\n", aContext, ok );
+  return ok;
 } // TzDaylightToContext
 
 
@@ -991,14 +1012,14 @@ static string PeeledStr( const string &aStr, const string &bv, const string &ev,
   }
   else {
     sInt32 i= 1;
-    
+
     while (true) {
       bp= FindProperty( aStr, bv, bp ); if (bp==string::npos) return "";
       if (i>=aNth) break;
       i++; bp++;
     } // while
   } // if
-  
+
 //string::size_type bp= aStr.find( bv, 0 ); if (bp==string::npos) return "";
   string::size_type ep= FindProperty( aStr, ev, bp ); if (ep==string::npos) return "";
 
